@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.14_04';
+our $VERSION = '0.14_05';
 $VERSION =~ tr/_//d;
 
 BEGIN {
@@ -15,10 +15,7 @@ BEGIN {
 
 sub _warn { warn &_longmess }
 
-sub _die {
-  die @_ if ref $_[0];
-  die &_longmess;
-}
+sub _die { die ref $_[0] ? @_ : &_longmess }
 
 sub _longmess {
   if ($_[-1] =~ /\n\z/) {
